@@ -30,7 +30,7 @@ from bs4 import BeautifulSoup
 
 __author__ = "Jordan Wildon (@jordanwildon)"
 __license__ = "MIT License"
-__version__ = "2.1.8"
+__version__ = "2.1.9"
 __maintainer__ = "Jordan Wildon"
 __email__ = "j.wildon@pm.me"
 __status__ = "Development"
@@ -101,9 +101,11 @@ user_agent = [
             help = 'Finds users near to specified coordinates.')
 @click.option('--alt', '-a', is_flag = True, default = False,
             help = 'Uses an alternative login.')
+@click.option('--json', '-j', is_flag = True, default = False,
+            help = 'Export to JSON')
 
 
-def cli(target,comprehensive,media,forwards,user,location,alt):
+def cli(target,comprehensive,media,forwards,user,location,alt,json):
 
     print(Fore.GREEN + """
       ______     __                 __  __
@@ -113,7 +115,7 @@ def cli(target,comprehensive,media,forwards,user,location,alt):
     /_/  \___/_/\___/ .___/\__,_/\__/_/ /_/\__, /
                    /_/                    /____/
     -- An OSINT toolkit for investigating Telegram chats.
-    -- Developed by @jordanwildon | Version 2.1.8.
+    -- Developed by @jordanwildon | Version 2.1.9.
     """)
 
     print(Style.RESET_ALL)
@@ -129,6 +131,16 @@ def cli(target,comprehensive,media,forwards,user,location,alt):
     else:
         alt_check = False
 
+    if json:
+        json_check = True
+        json_file = telepathy_file + 'json_files/'
+        try:
+            os.makedirs(json_file)
+        except FileExistsError:
+            pass
+    else:
+        json_check = False
+
     if alt_check == True:
         login = telepathy_file + 'login_alt.txt'
 
@@ -274,10 +286,11 @@ def cli(target,comprehensive,media,forwards,user,location,alt):
                         day = format(message.date.day, '02d')
                         hour = format(message.date.hour, '02d')
                         minute = format(message.date.minute, '02d')
+                        second = format(message.date.second, '02d')
 
                         date = str(year) + "/" + str(month) + "/" + str(day)
-                        mtime = str(hour) + ":" + str(minute)
-                        first_post = date + ", " + mtime + ' UTC'
+                        mtime = str(hour) + ":" + str(minute) + ":" + str(second)
+                        first_post = date + "T" + mtime + '+00:00 UTC'
                         break
 
                     if entity.username:
@@ -383,6 +396,14 @@ def cli(target,comprehensive,media,forwards,user,location,alt):
                         with open(memberlist_filename,'w+', encoding="utf-8") as save_members:
                             members_df.to_csv(save_members, sep=';')
 
+
+                        if json_check == True:
+                            members_df.to_json(json_file + alphanumeric
+                                                +'_memberlist.json', orient = 'records',
+                                                compression = 'infer', lines = True, index = True)
+                        else:
+                            pass
+
                         found_participants = len(all_participants)
                         found_participants = int(found_participants)
                         found_percentage = int(found_participants) / int(total_participants) * 100
@@ -491,8 +512,8 @@ def cli(target,comprehensive,media,forwards,user,location,alt):
 
                         forwards_df = pd.DataFrame(forwards_list,
                                                  columns = ['To', 'To_title',
-                                                            'From', 'From_ID', 'Username',
-                                                            'Timestamp'])
+                                                            'From', 'From_ID',
+                                                            'Username', 'Timestamp'])
 
 
                         async for message in client.iter_messages(t):
@@ -523,10 +544,11 @@ def cli(target,comprehensive,media,forwards,user,location,alt):
                                             day = format(message.date.day, '02d')
                                             hour = format(message.date.hour, '02d')
                                             minute = format(message.date.minute, '02d')
+                                            second = format(message.date.second, '02d')
 
                                             date = str(year) + "/" + str(month) + "/" + str(day)
-                                            mtime = str(hour) + ":" + str(minute)
-                                            timestamp = date + ", " + mtime
+                                            mtime = str(hour) + ":" + str(minute) + ":" + str(second)
+                                            timestamp = date + 'T' + mtime + '+00:00'
 
                                             substring = "PeerUser"
                                             string = str(f_from_id)
@@ -558,6 +580,13 @@ def cli(target,comprehensive,media,forwards,user,location,alt):
                                     with open(edgelist_file,'w+', encoding="utf-8") as save_forwards:
                                         forwards_df.to_csv(save_forwards, sep=';')
 
+                                    if json_check == True:
+                                        forwards_df.to_json(json_file + alphanumeric
+                                                            +'_edgelist.json', orient = 'records',
+                                                            compression = 'infer', lines = True, index = True)
+                                    else:
+                                        pass
+
                         if forward_count >= 15:
                             forwards_found = forwards_df.From.count()
                             value_count = forwards_df['From'].value_counts()
@@ -643,8 +672,6 @@ def cli(target,comprehensive,media,forwards,user,location,alt):
                             forward_count = 0
                             private_count = 0
 
-
-
                             if media_archive is True:
                                 print(Fore.GREEN + ' [!] '
                                       + Style.RESET_ALL
@@ -697,10 +724,11 @@ def cli(target,comprehensive,media,forwards,user,location,alt):
                                             day = str(format(message.date.day, '02d'))
                                             hour = str(format(message.date.hour, '02d'))
                                             minute = str(format(message.date.minute, '02d'))
+                                            second = str(format(message.date.second, '02d'))
 
                                             date = year + "-" + month + "-" + day
-                                            mtime = hour + ":" + minute
-                                            timestamp = date + ', ' + mtime
+                                            mtime = hour + ":" + minute + ":" + second
+                                            timestamp = date + 'T' + mtime + '+00:00'
 
                                             reply = message.reply_to_msg_id
 
@@ -809,9 +837,23 @@ def cli(target,comprehensive,media,forwards,user,location,alt):
                             with open(file_archive,'w+', encoding="utf-8") as archive_file:
                                 c_archive.to_csv(archive_file, sep=';')
 
+                            if json_check == True:
+                                c_archive.to_json(json_file + alphanumeric
+                                                    +'_archive.json', orient = 'records',
+                                                    compression = 'infer', lines = True, index = True)
+                            else:
+                                pass
+
                             if forward_check is True:
                                 with open(file_forwards, 'w+', encoding="utf-8") as forwards_file:
                                     c_forwards.to_csv(forwards_file, sep=';')
+
+                                if json_check == True:
+                                    c_forwards.to_json(json_file + alphanumeric
+                                                        +'_edgelist.json', orient = 'records',
+                                                        compression = 'infer', lines = True, index = True)
+                                else:
+                                    pass
                             else:
                                 pass
 
@@ -823,22 +865,6 @@ def cli(target,comprehensive,media,forwards,user,location,alt):
                             most_used_words_filtered = {}
                             #message stats, top words
 
-                            #for display_name, message_text, timestamp in c_archive.itertuples(index=False):
-                            #    name = c_archive.display_name
-                            #    text = c_archive.message_text
-                            #    message_time = c_archive.timestamp
-
-                            #if text is not None:
-                            #    text = text.text.strip().lower()
-                            #else:
-                            #    text = ''
-                            #date = dt.strptime(message_time.split()[0], '%d.%m.%Y').strftime('%Y-%m-%d')
-                            #hr = int(message_time.split()[1][:2])
-
-                            #print(name)
-                            #print(text)
-                            #print(date)
-                            #print(hr)
 
 
                             if chat_type != 'Channel':
